@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Union
+from typing import Dict, Tuple, Union
 
 from . import parser
 from . import interpreter
@@ -25,8 +25,13 @@ def get_named_export(path: Union[Path, str], name: str) -> interpreter.Value:
         raise RuntimeError(f"{name} not in {path} exports")
     return module.exports[name]
 
+
 def render(path: Union[Path, str], *values: interpreter.Value, prettify: bool = True) -> str:
-    values = html.make_value_js_friendly(values)
+    if not isinstance(path, Path):
+        path = Path(path)
+
+    values = tuple(html.make_value_js_friendly(v) for v in values)
     f = get_default_export(path)
     assert isinstance(f, interpreter.Function)
-    return html.to_html(f(*values), prettify=prettify)
+    html_tree = f(*values)
+    return html.to_html(html.make_value_js_friendly(html_tree), prettify=prettify)
