@@ -27,19 +27,29 @@ SPACE_PATTERN = re.compile(r'^(\s*)', re.MULTILINE)
 
 
 def make_value_js_friendly(value: interpreter.Value) -> interpreter.Value:
+    if value is None or isinstance(value, (float, int, bool, str, builtins.TrustedHtml)):
+        return value
     if isinstance(value, dict):
         return {k: make_value_js_friendly(v) for k, v in value.items()}
     if isinstance(value, (list, tuple)):
         return [make_value_js_friendly(n) for n in value]
+    # we turn functions into null
+    if isinstance(value, interpreter.Function):
+        return None
     if is_dataclass(value):
         return make_value_js_friendly(asdict(value))
-    return value
+    # handle pydantic without importing it
+    if hasattr(value, "dict") and callable(value.dict):
+        return make_value_js_friendly(value.dict())
+    raise RuntimeError(f"unable to make type jsonable {type(value)}")
 
 
 def to_html(value: interpreter.Value, prettify: bool=True) -> str:
     assert builtins.is_renderable(value)
     if value is None:
         return ""
+    if isinstance(value, builtins.TrustedHtml):
+        return value.string
     if isinstance(value, str):
         return escape(value)
     if isinstance(value, (float, int)):
@@ -69,7 +79,7 @@ def to_html(value: interpreter.Value, prettify: bool=True) -> str:
     is_self_closing = tag in SELF_CLOSING and not children
     html_str = f"<{escape(tag)} {attrs_str}>"
     if not is_self_closing:
-        html_str += ''.join(to_html(c) for c in children)
+        html_str += ''.join(to_html(c, prettify=prettify) for c in children)
         html_str += f"</{escape(tag)}>"
     if prettify:
         html_str = BeautifulSoup(html_str, features="html.parser").prettify()
