@@ -2,7 +2,7 @@ from dataclasses import dataclass
 from functools import partial
 import math
 from pathlib import Path
-from typing import Any, Callable, Dict, List, Union
+from typing import Any, Callable, Dict, List, Tuple, Union
 
 from . import builtins, parser
 
@@ -48,9 +48,15 @@ class MakeFunction:
         return self.f(*args)
 
 
+CACHE: Dict[Tuple[str, float], Module] = {}
+
+
 def interpret(path: Path) -> Module:
-    with open(path) as f:
-        ast = parser.parse(f.read())
+    cache_key = str(path.resolve()), path.stat().st_mtime
+    ast = CACHE.get(cache_key)
+    if ast is None:
+        ast = parser.parse(path.read_text())
+        CACHE[cache_key] = ast
 
     module = Module(path=path, scope={}, exports={}, default_export=missing, value=missing)
     for node in ast.values:
@@ -88,7 +94,7 @@ def interpret(path: Path) -> Module:
 
 
 def get(scope: Scope, value: Value) -> Value:
-    if value is None or isinstance(value, (str, float, int, bool)):
+    if value is None or isinstance(value, (str, float, int, bool, builtins.TrustedHtml)):
         return value
     if isinstance(value, list):
         return list_handler(scope, value)
@@ -136,11 +142,14 @@ def dict_handler(scope: Scope, value: dict) -> Value:
     return out
 
 
+_m = MakeFunction(builtins.m)
+
+
 def var_handler(scope: Scope, value: parser.Var) -> Value:
     if value.name == "Object" and "Object" not in scope:
         return builtins.Object
     if value.name == "m" and "m" not in scope:
-        return MakeFunction(builtins.m)
+        return _m
     if value.name == "dedent" and "dedent" not in scope:
         return MakeFunction(builtins.dedent)
     return scope[value.name]
@@ -160,6 +169,10 @@ def dot_handler(scope: Scope, value: parser.Dot) -> Value:
         if name == "includes":
             return MakeFunction(partial(builtins.includes, left))
 
+    if left is _m:
+        if name == "trust":
+            return MakeFunction(builtins.m_dot_trust)
+
     if left is builtins.Object:
         if name == "fromEntries":
             return MakeFunction(builtins.from_entries)
@@ -189,7 +202,8 @@ def function_handler(scope: Scope, value: parser.Function) -> Value:
 def function_call_handler(scope: Scope, value: parser.FunctionCall) -> Value:
     function = get(scope, value.var)
     values = get(scope, value.values)
-    assert isinstance(function, Function) or isinstance(function, MakeFunction)
+    if not (isinstance(function, Function) or isinstance(function, MakeFunction)):
+        raise ValueError(f"{function} is not of type Function")
     return function(*values)
 
 
